@@ -74,7 +74,7 @@ module NumRu
 
     def get_record(io,flag_read=true)
       str = io.read(4)
-      unless str.length==4
+      unless str && str.length==4
         return [nil,nil,nil]
       end
       len = str.unpack("N")[0]
@@ -666,7 +666,7 @@ module NumRu
         fpat = File.join(fpat,fname[0]) if fname
       end
 
-      ary = Array.new
+#      ary = Array.new
       fpat.sub!(/_model/,@type1[0,4])
       fpat.sub!(/_space/,@type1[-4,4])
       fpat.sub!(/_2d/,@type1[4,2])
@@ -684,7 +684,6 @@ module NumRu
       else
         fpats = [fpat]
       end
-
       ary = Array.new
       fpats.each{|s|
         s.gsub!(/\s/,'_')
@@ -708,7 +707,7 @@ module NumRu
           get_version(file) unless @meta[:version] 
           name, mtime, str = get_record(file)
 	  unless name == "NUSD"
-            warn("NUSD record is invalid") if $DEBUG
+            warn("NUSD record is invalid (#{fname})") if $DEBUG
 	    file.close
 	    next
 	  end
@@ -716,7 +715,7 @@ module NumRu
 
           name, mtime, str = get_record(file)
           unless name == "CNTL"
-            warn("CNTL record is invalid") if $DEBUG
+            warn("CNTL record is invalid (#{fname})") if $DEBUG
             file.close
             next
           end
@@ -728,7 +727,7 @@ module NumRu
           when "INDY"
             hash.update parse_indy(str,hash)
           else
-            warn("INDX or INDY record is invalid") if $DEBUG
+            warn("INDX or INDY record is invalid (#{fname})") if $DEBUG
             file.close
             next
           end
@@ -1238,10 +1237,11 @@ module NumRu
       end
 
       if @meta[:projection] == "RG  "
-        lon = dim("x")
+#        lon = dim("x")
+        lon = dim("lon").val(:full) # OBTAIN 2D ARRAY OF LON TO GET MASK
         ind = NArray.int(nx,ny)
         if NArrayMiss === lon
-          mask = lon.mask
+          mask = lon.get_mask
           ind[mask] = NArray.int(mask.count_true).indgen
           mask = mask[ix,iy]
         else
@@ -1297,7 +1297,9 @@ module NumRu
       }
 
       if @meta[:projection] == "RG  "
-        shape = [ind[0], ind[1]] + ary.shape[2..-1]
+        #shape = [ind[0], ind[1]] + ary.shape[2..-1]
+        tmpshape = shape[0..1]
+        shape = tmpshape + ary.shape[2..-1]
         ary2 = ary.class.new(ary.typecode, *shape)
         if mask
           if NArray === ary
@@ -1372,6 +1374,23 @@ module NumRu
       get(*inds).typecode
     end
 
+=begin rdoc
+ get grid infromation
+=end
+    def grid
+			h = Hash.new
+			h[:size] = @meta[:size]
+			h[:distance] = @meta[:distance]
+			h[:basepoint]=@meta[:basepoint]
+			h[:basepoint2]=@meta[:basepoint2]
+			h[:standard]=@meta[:standard]
+			h[:standard2]=@meta[:standard2]
+			h[:others] = @meta[:others]
+			h[:others2] = @meta[:others2]
+			h[:projection] = @meta[:projection]
+			return h
+		end
+
     private
 
     def parse_data(io, pos, len)
@@ -1695,9 +1714,11 @@ module NumRu
 
       if @name2 == "validtime"
         @attr["units"] = @meta[:validtime_unit].downcase
+        @attr["long_name"] = "valid time"
       end
       if @name2 == "basetime"
         @attr["units"] = "minutes since 1801-01-01 00:00:0.0"
+        @attr["long_name"] = "base time"
       end
 
     end
@@ -1961,8 +1982,8 @@ module NumRu
         lat = NArrayMiss.sfloat(i_n_max,j_n)
         itotal = 0
         j_n.times{|jj|
-          xi = NArray.sfloat(i_n[jj]).indgen(i_start[jj])
-          lon[0...i_n[jj],jj] = (xi-bi)*360.0/i[jj] + bx
+          xi = NArray.sfloat(i_n[jj]).indgen
+          lon[0...i_n[jj],jj] = xi*360.0/i[jj] + bx
           lat[0...i_n[jj],jj] = parm[:lat][jj]
         }
         if lon.get_mask!.count_false == 0
